@@ -8,7 +8,7 @@ impl QueryBuilder for PostgresQueryBuilder {
 
     fn prepare_returning(
         &self,
-        returning: &Vec<SelectExpr>,
+        returning: &[SelectExpr],
         sql: &mut SqlWriter,
         collector: &mut dyn FnMut(Value),
     ) {
@@ -45,9 +45,10 @@ impl QueryBuilder for PostgresQueryBuilder {
         collector: &mut dyn FnMut(Value),
     ) {
         match bin_oper {
-            BinOper::Matches => write!(sql, "{}", "@@").unwrap(),
-            BinOper::Contains => write!(sql, "{}", "@>").unwrap(),
-            BinOper::Contained => write!(sql, "{}", "<@").unwrap(),
+            BinOper::Matches => write!(sql, "@@").unwrap(),
+            BinOper::Contains => write!(sql, "@>").unwrap(),
+            BinOper::Contained => write!(sql, "<@").unwrap(),
+            BinOper::Concatenate => write!(sql, "||").unwrap(),
             _ => self.prepare_bin_oper_common(bin_oper, sql, collector),
         }
     }
