@@ -121,6 +121,11 @@ pub trait QueryBuilder: QuotedBuilder {
             write!(sql, " OFFSET ").unwrap();
             self.prepare_value(offset, sql, collector);
         }
+
+        if let Some(lock) = &select.lock {
+            write!(sql, " ").unwrap();
+            self.prepare_select_lock(lock, sql, collector);
+        }
     }
 
     /// Translate [`UpdateStatement`] into SQL statement.
@@ -290,17 +295,12 @@ pub trait QueryBuilder: QuotedBuilder {
                     match tok {
                         Token::Punctuation(mark) => {
                             if mark == "?" {
-                                if let Some(nxt) = tokenizer.peek() {
-                                    match nxt {
-                                        Token::Punctuation(mark) => {
-                                            // escape '??'
-                                            if mark == "?" {
-                                                write!(sql, "{}", mark).unwrap();
-                                                tokenizer.next();
-                                                continue;
-                                            }
-                                        }
-                                        _ => {}
+                                if let Some(Token::Punctuation(mark)) = tokenizer.peek() {
+                                    // escape '??'
+                                    if mark == "?" {
+                                        write!(sql, "{}", mark).unwrap();
+                                        tokenizer.next();
+                                        continue;
                                     }
                                 }
                                 self.prepare_value(&values[count], sql, collector);
@@ -338,6 +338,24 @@ pub trait QueryBuilder: QuotedBuilder {
         .unwrap();
     }
 
+    /// Translate [`LockType`] into SQL statement.
+    fn prepare_select_lock(
+        &self,
+        select_lock: &LockType,
+        sql: &mut SqlWriter,
+        _collector: &mut dyn FnMut(Value),
+    ) {
+        write!(
+            sql,
+            "{}",
+            match select_lock {
+                LockType::Shared => "FOR SHARE",
+                LockType::Exclusive => "FOR UPDATE",
+            }
+        )
+        .unwrap();
+    }
+
     /// Translate [`SelectExpr`] into SQL statement.
     fn prepare_select_expr(
         &self,
@@ -583,10 +601,7 @@ pub trait QueryBuilder: QuotedBuilder {
         collector: &mut dyn FnMut(Value),
     ) {
         match join_on {
-            JoinOn::Condition(c) => {
-                write!(sql, "ON ").unwrap();
-                self.prepare_simple_expr(c, sql, collector);
-            }
+            JoinOn::Condition(c) => self.prepare_condition(c, "ON", sql, collector),
             JoinOn::Columns(_c) => unimplemented!(),
         }
     }
@@ -707,7 +722,7 @@ pub trait QueryBuilder: QuotedBuilder {
     /// Hook to insert "RETURNING" statements.
     fn prepare_returning(
         &self,
-        _returning: &Vec<SelectExpr>,
+        _returning: &[SelectExpr],
         _sql: &mut SqlWriter,
         _collector: &mut dyn FnMut(Value),
     ) {
@@ -739,7 +754,7 @@ pub trait QueryBuilder: QuotedBuilder {
                 }
             }
             ConditionHolderContents::Condition(c) => {
-                self.prepare_condition_where(&c, sql, collector);
+                self.prepare_condition_where(c, sql, collector);
             }
         }
     }
@@ -767,7 +782,7 @@ pub trait QueryBuilder: QuotedBuilder {
                     if condition.conditions.len() > 1 {
                         write!(sql, "(").unwrap();
                     }
-                    self.prepare_condition_where(&c, sql, collector);
+                    self.prepare_condition_where(c, sql, collector);
                     if condition.conditions.len() > 1 {
                         write!(sql, ")").unwrap();
                     }
@@ -776,7 +791,7 @@ pub trait QueryBuilder: QuotedBuilder {
                     if condition.conditions.len() > 1 && (e.is_logical() || e.is_between()) {
                         write!(sql, "(").unwrap();
                     }
-                    self.prepare_simple_expr(&e, sql, collector);
+                    self.prepare_simple_expr(e, sql, collector);
                     if condition.conditions.len() > 1 && (e.is_logical() || e.is_between()) {
                         write!(sql, ")").unwrap();
                     }
