@@ -56,7 +56,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -79,7 +79,7 @@ impl Expr {
     /// ```
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -112,7 +112,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -146,7 +146,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -181,7 +181,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -211,7 +211,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -246,7 +246,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -276,7 +276,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -299,43 +299,34 @@ impl Expr {
     /// );
     /// ```
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .expr(Expr::cust_with_values("6 = ? * ?", vec![2, 3]))
     ///     .to_owned();
     ///
-    /// assert_eq!(
-    ///     query.to_string(MysqlQueryBuilder),
-    ///     r#"SELECT 6 = 2 * 3"#
-    /// );
-    /// assert_eq!(
-    ///     query.to_string(PostgresQueryBuilder),
-    ///     r#"SELECT 6 = 2 * 3"#
-    /// );
-    /// assert_eq!(
-    ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT 6 = 2 * 3"#
-    /// );
+    /// assert_eq!(query.to_string(MysqlQueryBuilder), r#"SELECT 6 = 2 * 3"#);
+    /// assert_eq!(query.to_string(PostgresQueryBuilder), r#"SELECT 6 = 2 * 3"#);
+    /// assert_eq!(query.to_string(SqliteQueryBuilder), r#"SELECT 6 = 2 * 3"#);
     /// ```
     /// Postgres only: use `??` to escape `?`
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .expr(Expr::cust_with_values("? ?? ?", vec!["a", "b"]))
     ///     .to_owned();
     ///
-    /// assert_eq!(
-    ///     query.to_string(PostgresQueryBuilder),
-    ///     r#"SELECT 'a' ? 'b'"#
-    /// );
+    /// assert_eq!(query.to_string(PostgresQueryBuilder), r#"SELECT 'a' ? 'b'"#);
     /// ```
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
-    ///     .expr(Expr::cust_with_values("data @?? (?::JSONPATH)", vec!["hello"]))
+    ///     .expr(Expr::cust_with_values(
+    ///         "data @?? (?::JSONPATH)",
+    ///         vec!["hello"],
+    ///     ))
     ///     .to_owned();
     ///
     /// assert_eq!(
@@ -462,7 +453,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -495,7 +486,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -528,7 +519,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -561,7 +552,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -594,7 +585,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -628,7 +619,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -662,7 +653,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -696,7 +687,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
@@ -943,7 +934,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).max())
@@ -973,7 +964,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).min())
@@ -1003,7 +994,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).sum())
@@ -1033,7 +1024,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).count())
@@ -1063,7 +1054,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .expr(Expr::tbl(Char::Table, Char::SizeW).if_null(0))
@@ -1099,7 +1090,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Id])
@@ -1122,7 +1113,7 @@ impl Expr {
     /// ```
     /// Empty value list
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Id])
@@ -1161,7 +1152,7 @@ impl Expr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Id])
@@ -1184,7 +1175,7 @@ impl Expr {
     /// ```
     /// Empty value list
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .columns(vec![Char::Id])
@@ -1373,6 +1364,42 @@ impl Expr {
         self.bin_oper(BinOper::Contained, expr.into())
     }
 
+    /// Express an postgres concatenate (`||`) expression.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .columns(vec![Font::Name, Font::Variant, Font::Language])
+    ///     .from(Font::Table)
+    ///     .and_where(Expr::val("a").concatenate(Expr::val("b")))
+    ///     .and_where(Expr::val("c").concat(Expr::val("d")))
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "name", "variant", "language" FROM "font" WHERE 'a' || 'b' AND 'c' || 'd'"#
+    /// );
+    /// ```
+    #[cfg(feature = "backend-postgres")]
+    pub fn concatenate<T>(self, expr: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        self.bin_oper(BinOper::Concatenate, expr.into())
+    }
+
+    /// Alias of [`Expr::concatenate`]
+    #[cfg(feature = "backend-postgres")]
+    pub fn concat<T>(self, expr: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        self.concatenate(expr)
+    }
+
     pub(crate) fn func(func: Function) -> Self {
         let mut expr = Expr::new();
         expr.func = Some(func);
@@ -1420,6 +1447,7 @@ impl Expr {
     }
 }
 
+#[allow(clippy::from_over_into)]
 impl Into<SimpleExpr> for Expr {
     /// Convert into SimpleExpr. Will panic if this Expr is missing an operand
     fn into(self) -> SimpleExpr {
@@ -1441,6 +1469,7 @@ impl Into<SimpleExpr> for Expr {
     }
 }
 
+#[allow(clippy::from_over_into)]
 impl Into<SelectExpr> for Expr {
     fn into(self) -> SelectExpr {
         self.into_simple_expr().into()
@@ -1515,12 +1544,16 @@ impl SimpleExpr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
     ///     .from(Char::Table)
-    ///     .and_where(Expr::col(Char::SizeW).mul(2).equals(Expr::col(Char::SizeH).mul(3)))
+    ///     .and_where(
+    ///         Expr::col(Char::SizeW)
+    ///             .mul(2)
+    ///             .equals(Expr::col(Char::SizeH).mul(3)),
+    ///     )
     ///     .to_owned();
     ///
     /// assert_eq!(
@@ -1548,12 +1581,16 @@ impl SimpleExpr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
     ///     .from(Char::Table)
-    ///     .and_where(Expr::col(Char::SizeW).mul(2).not_equals(Expr::col(Char::SizeH)))
+    ///     .and_where(
+    ///         Expr::col(Char::SizeW)
+    ///             .mul(2)
+    ///             .not_equals(Expr::col(Char::SizeH)),
+    ///     )
     ///     .to_owned();
     ///
     /// assert_eq!(
@@ -1581,10 +1618,14 @@ impl SimpleExpr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
-    ///     .expr(Expr::col(Char::SizeW).max().add(Expr::col(Char::SizeH).max()))
+    ///     .expr(
+    ///         Expr::col(Char::SizeW)
+    ///             .max()
+    ///             .add(Expr::col(Char::SizeH).max()),
+    ///     )
     ///     .from(Char::Table)
     ///     .to_owned();
     ///
@@ -1614,10 +1655,14 @@ impl SimpleExpr {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
-    ///     .expr(Expr::col(Char::SizeW).max().sub(Expr::col(Char::SizeW).min()))
+    ///     .expr(
+    ///         Expr::col(Char::SizeW)
+    ///             .max()
+    ///             .sub(Expr::col(Char::SizeW).min()),
+    ///     )
     ///     .from(Char::Table)
     ///     .to_owned();
     ///
@@ -1707,4 +1752,44 @@ impl SimpleExpr {
             _ => None,
         }
     }
+
+    /// Express an postgres concatenate (`||`) expression.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .columns(vec![Font::Name, Font::Variant, Font::Language])
+    ///     .from(Font::Table)
+    ///     .and_where(
+    ///         Expr::val("a")
+    ///             .concatenate(Expr::val("b"))
+    ///             .concat(Expr::val("c"))
+    ///             .concat(Expr::val("d")),
+    ///     )
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "name", "variant", "language" FROM "font" WHERE 'a' || 'b' || 'c' || 'd'"#
+    /// );
+    /// ```
+    #[cfg(feature = "backend-postgres")]
+    pub fn concatenate<T>(self, right: T) -> Self
+    where
+        T: Into<SimpleExpr>,
+    {
+        self.binary(BinOper::Concatenate, right.into())
+    }
+
+    /// Alias of [`SimpleExpr::concatenate`]
+    #[cfg(feature = "backend-postgres")]
+    pub fn concat<T>(self, right: T) -> Self
+    where
+        T: Into<SimpleExpr>,
+    {
+        self.concatenate(right)
+    }
 }
