@@ -7,7 +7,6 @@ use crate::{
     value::*,
     QueryStatementBuilder,
 };
-use std::iter::FromIterator;
 
 /// Select rows from an existing table
 ///
@@ -18,7 +17,7 @@ use std::iter::FromIterator;
 ///
 /// let query = Query::select()
 ///     .column(Char::Character)
-///     .table_column(Font::Table, Font::Name)
+///     .column((Font::Table, Font::Name))
 ///     .from(Char::Table)
 ///     .left_join(Font::Table, Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
 ///     .and_where(Expr::col(Char::SizeW).is_in(vec![3, 4]))
@@ -50,6 +49,7 @@ pub struct SelectStatement {
     pub(crate) orders: Vec<OrderExpr>,
     pub(crate) limit: Option<Value>,
     pub(crate) offset: Option<Value>,
+    pub(crate) lock: Option<LockType>,
 }
 
 /// List of distinct keywords that can be used in select statement
@@ -75,6 +75,14 @@ pub struct JoinExpr {
     pub on: Option<JoinOn>,
 }
 
+/// List of lock types that can be used in select statement
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
+pub enum LockType {
+    Shared,
+    Exclusive,
+}
+
+#[allow(clippy::from_over_into)]
 impl Into<SelectExpr> for SimpleExpr {
     fn into(self) -> SelectExpr {
         SelectExpr {
@@ -104,6 +112,7 @@ impl SelectStatement {
             orders: Vec::new(),
             limit: None,
             offset: None,
+            lock: None,
         }
     }
 
@@ -111,15 +120,16 @@ impl SelectStatement {
     pub fn take(&mut self) -> Self {
         Self {
             distinct: self.distinct.take(),
-            selects: std::mem::replace(&mut self.selects, Vec::new()),
+            selects: std::mem::take(&mut self.selects),
             from: self.from.take(),
-            join: std::mem::replace(&mut self.join, Vec::new()),
+            join: std::mem::take(&mut self.join),
             wherei: std::mem::replace(&mut self.wherei, ConditionHolder::new()),
-            groups: std::mem::replace(&mut self.groups, Vec::new()),
+            groups: std::mem::take(&mut self.groups),
             having: std::mem::replace(&mut self.having, ConditionHolder::new()),
-            orders: std::mem::replace(&mut self.orders, Vec::new()),
+            orders: std::mem::take(&mut self.orders),
             limit: self.limit.take(),
             offset: self.offset.take(),
+            lock: self.lock.take(),
         }
     }
 
@@ -128,15 +138,19 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
     ///     .from(Char::Table)
     ///     .conditions(
     ///         true,
-    ///         |x| { x.and_where(Expr::col(Char::FontId).eq(5)); },
-    ///         |x| { x.and_where(Expr::col(Char::FontId).eq(10)); }
+    ///         |x| {
+    ///             x.and_where(Expr::col(Char::FontId).eq(5));
+    ///         },
+    ///         |x| {
+    ///             x.and_where(Expr::col(Char::FontId).eq(10));
+    ///         },
     ///     )
     ///     .to_owned();
     ///
@@ -177,15 +191,13 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .from(Char::Table)
     ///     .expr(Expr::val(42))
     ///     .expr(Expr::col(Char::Id).max())
-    ///     .expr((1..10_i32).fold(Expr::value(0), |expr, i| {
-    ///         expr.add(Expr::value(i))
-    ///     }))
+    ///     .expr((1..10_i32).fold(Expr::value(0), |expr, i| expr.add(Expr::value(i))))
     ///     .to_owned();
     ///
     /// assert_eq!(
@@ -214,15 +226,13 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .from(Char::Table)
     ///     .exprs(vec![
     ///         Expr::col(Char::Id).max(),
-    ///         (1..10_i32).fold(Expr::value(0), |expr, i| {
-    ///             expr.add(Expr::value(i))
-    ///         }),
+    ///         (1..10_i32).fold(Expr::value(0), |expr, i| expr.add(Expr::value(i))),
     ///     ])
     ///     .to_owned();
     ///
@@ -267,7 +277,7 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .from(Char::Table)
@@ -291,7 +301,7 @@ impl SelectStatement {
     /// ```
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .from(Char::Table)
@@ -335,15 +345,11 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .from(Char::Table)
-    ///     .columns(vec![
-    ///         Char::Character,
-    ///         Char::SizeW,
-    ///         Char::SizeH,
-    ///     ])
+    ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
     ///     .to_owned();
     ///
     /// assert_eq!(
@@ -418,7 +424,7 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .from(Char::Table)
@@ -467,7 +473,7 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .column(Char::FontSize)
@@ -489,7 +495,7 @@ impl SelectStatement {
     /// ```
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .column(Char::FontSize)
@@ -525,7 +531,7 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .column(Char::FontSize)
@@ -558,13 +564,13 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let table_as: DynIden = SeaRc::new(Alias::new("char"));
     ///
     /// let query = Query::select()
     ///     .from_as(Char::Table, table_as.clone())
-    ///     .table_column(table_as.clone(), Char::Character)
+    ///     .column((table_as.clone(), Char::Character))
     ///     .to_owned();
     ///
     /// assert_eq!(
@@ -582,13 +588,13 @@ impl SelectStatement {
     /// ```
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let table_as = Alias::new("alias");
     ///
     /// let query = Query::select()
     ///     .from_as((Font::Table, Char::Table), table_as.clone())
-    ///     .table_column(table_as, Char::Character)
+    ///     .column((table_as, Char::Character))
     ///     .to_owned();
     ///
     /// assert_eq!(
@@ -647,20 +653,16 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
-    ///     .columns(vec![
-    ///         Glyph::Image
-    ///     ])
+    ///     .columns(vec![Glyph::Image])
     ///     .from_subquery(
     ///         Query::select()
-    ///             .columns(vec![
-    ///                 Glyph::Image, Glyph::Aspect
-    ///             ])
+    ///             .columns(vec![Glyph::Image, Glyph::Aspect])
     ///             .from(Glyph::Table)
     ///             .take(),
-    ///         Alias::new("subglyph")
+    ///         Alias::new("subglyph"),
     ///     )
     ///     .to_owned();
     ///
@@ -698,7 +700,7 @@ impl SelectStatement {
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
-    ///     .table_column(Font::Table, Font::Name)
+    ///     .column((Font::Table, Font::Name))
     ///     .from(Char::Table)
     ///     .left_join(Font::Table, Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
     ///     .to_owned();
@@ -715,10 +717,27 @@ impl SelectStatement {
     ///     query.to_string(SqliteQueryBuilder),
     ///     r#"SELECT `character`, `font`.`name` FROM `character` LEFT JOIN `font` ON `character`.`font_id` = `font`.`id`"#
     /// );
+    ///
+    /// // Constructing chained join conditions
+    /// assert_eq!(
+    ///     Query::select()
+    ///         .column(Char::Character)
+    ///         .column((Font::Table, Font::Name))
+    ///         .from(Char::Table)
+    ///         .left_join(
+    ///             Font::Table,
+    ///             Condition::all()
+    ///                 .add(Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
+    ///                 .add(Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
+    ///         )
+    ///         .to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `font`.`name` FROM `character` LEFT JOIN `font` ON `character`.`font_id` = `font`.`id` AND `character`.`font_id` = `font`.`id`"#
+    /// );
     /// ```
-    pub fn left_join<R>(&mut self, tbl_ref: R, condition: SimpleExpr) -> &mut Self
+    pub fn left_join<R, C>(&mut self, tbl_ref: R, condition: C) -> &mut Self
     where
         R: IntoTableRef,
+        C: IntoCondition,
     {
         self.join(JoinType::LeftJoin, tbl_ref, condition)
     }
@@ -732,7 +751,7 @@ impl SelectStatement {
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
-    ///     .table_column(Font::Table, Font::Name)
+    ///     .column((Font::Table, Font::Name))
     ///     .from(Char::Table)
     ///     .inner_join(Font::Table, Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
     ///     .to_owned();
@@ -749,10 +768,27 @@ impl SelectStatement {
     ///     query.to_string(SqliteQueryBuilder),
     ///     r#"SELECT `character`, `font`.`name` FROM `character` INNER JOIN `font` ON `character`.`font_id` = `font`.`id`"#
     /// );
+    ///
+    /// // Constructing chained join conditions
+    /// assert_eq!(
+    ///     Query::select()
+    ///         .column(Char::Character)
+    ///         .column((Font::Table, Font::Name))
+    ///         .from(Char::Table)
+    ///         .inner_join(
+    ///             Font::Table,
+    ///             Condition::all()
+    ///                 .add(Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
+    ///                 .add(Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
+    ///         )
+    ///         .to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `font`.`name` FROM `character` INNER JOIN `font` ON `character`.`font_id` = `font`.`id` AND `character`.`font_id` = `font`.`id`"#
+    /// );
     /// ```
-    pub fn inner_join<R>(&mut self, tbl_ref: R, condition: SimpleExpr) -> &mut Self
+    pub fn inner_join<R, C>(&mut self, tbl_ref: R, condition: C) -> &mut Self
     where
         R: IntoTableRef,
+        C: IntoCondition,
     {
         self.join(JoinType::InnerJoin, tbl_ref, condition)
     }
@@ -766,7 +802,7 @@ impl SelectStatement {
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
-    ///     .table_column(Font::Table, Font::Name)
+    ///     .column((Font::Table, Font::Name))
     ///     .from(Char::Table)
     ///     .join(JoinType::RightJoin, Font::Table, Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
     ///     .to_owned();
@@ -783,15 +819,35 @@ impl SelectStatement {
     ///     query.to_string(SqliteQueryBuilder),
     ///     r#"SELECT `character`, `font`.`name` FROM `character` RIGHT JOIN `font` ON `character`.`font_id` = `font`.`id`"#
     /// );
+    ///
+    /// // Constructing chained join conditions
+    /// assert_eq!(
+    ///     Query::select()
+    ///         .column(Char::Character)
+    ///         .column((Font::Table, Font::Name))
+    ///         .from(Char::Table)
+    ///         .join(
+    ///             JoinType::RightJoin,
+    ///             Font::Table,
+    ///             Condition::all()
+    ///                 .add(Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
+    ///                 .add(Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
+    ///         )
+    ///         .to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `font`.`name` FROM `character` RIGHT JOIN `font` ON `character`.`font_id` = `font`.`id` AND `character`.`font_id` = `font`.`id`"#
+    /// );
     /// ```
-    pub fn join<R>(&mut self, join: JoinType, tbl_ref: R, condition: SimpleExpr) -> &mut Self
+    pub fn join<R, C>(&mut self, join: JoinType, tbl_ref: R, condition: C) -> &mut Self
     where
         R: IntoTableRef,
+        C: IntoCondition,
     {
         self.join_join(
             join,
             tbl_ref.into_table_ref(),
-            JoinOn::Condition(Box::new(condition)),
+            JoinOn::Condition(Box::new(ConditionHolder::new_with_condition(
+                condition.into_condition(),
+            ))),
         )
     }
 
@@ -804,7 +860,7 @@ impl SelectStatement {
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
-    ///     .table_column(Font::Table, Font::Name)
+    ///     .column((Font::Table, Font::Name))
     ///     .from(Char::Table)
     ///     .join_as(
     ///         JoinType::RightJoin,
@@ -826,22 +882,43 @@ impl SelectStatement {
     ///     query.to_string(SqliteQueryBuilder),
     ///     r#"SELECT `character`, `font`.`name` FROM `character` RIGHT JOIN `font` AS `f` ON `character`.`font_id` = `font`.`id`"#
     /// );
+    ///
+    /// // Constructing chained join conditions
+    /// assert_eq!(
+    ///     Query::select()
+    ///         .column(Char::Character)
+    ///         .column((Font::Table, Font::Name))
+    ///         .from(Char::Table)
+    ///         .join_as(
+    ///             JoinType::RightJoin,
+    ///             Font::Table,
+    ///             Alias::new("f"),
+    ///             Condition::all()
+    ///                 .add(Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
+    ///                 .add(Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
+    ///         )
+    ///         .to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `font`.`name` FROM `character` RIGHT JOIN `font` AS `f` ON `character`.`font_id` = `font`.`id` AND `character`.`font_id` = `font`.`id`"#
+    /// );
     /// ```
-    pub fn join_as<R, A>(
+    pub fn join_as<R, A, C>(
         &mut self,
         join: JoinType,
         tbl_ref: R,
         alias: A,
-        condition: SimpleExpr,
+        condition: C,
     ) -> &mut Self
     where
         R: IntoTableRef,
         A: IntoIden,
+        C: IntoCondition,
     {
         self.join_join(
             join,
             tbl_ref.into_table_ref().alias(alias.into_iden()),
-            JoinOn::Condition(Box::new(condition)),
+            JoinOn::Condition(Box::new(ConditionHolder::new_with_condition(
+                condition.into_condition(),
+            ))),
         )
     }
 
@@ -849,16 +926,17 @@ impl SelectStatement {
         since = "0.6.1",
         note = "Please use the [`SelectStatement::join_as`] instead"
     )]
-    pub fn join_alias<R, A>(
+    pub fn join_alias<R, A, C>(
         &mut self,
         join: JoinType,
         tbl_ref: R,
         alias: A,
-        condition: SimpleExpr,
+        condition: C,
     ) -> &mut Self
     where
         R: IntoTableRef,
         A: IntoIden,
+        C: IntoCondition,
     {
         self.join_as(join, tbl_ref, alias, condition)
     }
@@ -876,10 +954,7 @@ impl SelectStatement {
     ///     .from(Font::Table)
     ///     .join_subquery(
     ///         JoinType::LeftJoin,
-    ///         Query::select()
-    ///             .column(Glyph::Id)
-    ///             .from(Glyph::Table)
-    ///             .take(),
+    ///         Query::select().column(Glyph::Id).from(Glyph::Table).take(),
     ///         sub_glyph.clone(),
     ///         Expr::tbl(Font::Table, Font::Id).equals(sub_glyph.clone(), Glyph::Id)
     ///     )
@@ -897,22 +972,41 @@ impl SelectStatement {
     ///     query.to_string(SqliteQueryBuilder),
     ///     r#"SELECT `name` FROM `font` LEFT JOIN (SELECT `id` FROM `glyph`) AS `sub_glyph` ON `font`.`id` = `sub_glyph`.`id`"#
     /// );
-    /// ```
     ///
-    pub fn join_subquery<T>(
+    /// // Constructing chained join conditions
+    /// assert_eq!(
+    ///     Query::select()
+    ///         .column(Font::Name)
+    ///         .from(Font::Table)
+    ///         .join_subquery(
+    ///             JoinType::LeftJoin,
+    ///             Query::select().column(Glyph::Id).from(Glyph::Table).take(),
+    ///             sub_glyph.clone(),
+    ///             Condition::all()
+    ///                 .add(Expr::tbl(Font::Table, Font::Id).equals(sub_glyph.clone(), Glyph::Id))
+    ///                 .add(Expr::tbl(Font::Table, Font::Id).equals(sub_glyph.clone(), Glyph::Id))
+    ///         )
+    ///         .to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `name` FROM `font` LEFT JOIN (SELECT `id` FROM `glyph`) AS `sub_glyph` ON `font`.`id` = `sub_glyph`.`id` AND `font`.`id` = `sub_glyph`.`id`"#
+    /// );
+    /// ```
+    pub fn join_subquery<T, C>(
         &mut self,
         join: JoinType,
         query: SelectStatement,
         alias: T,
-        condition: SimpleExpr,
+        condition: C,
     ) -> &mut Self
     where
         T: IntoIden,
+        C: IntoCondition,
     {
         self.join_join(
             join,
             TableRef::SubQuery(query, alias.into_iden()),
-            JoinOn::Condition(Box::new(condition)),
+            JoinOn::Condition(Box::new(ConditionHolder::new_with_condition(
+                condition.into_condition(),
+            ))),
         )
     }
 
@@ -934,7 +1028,7 @@ impl SelectStatement {
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
-    ///     .table_column(Font::Table, Font::Name)
+    ///     .column((Font::Table, Font::Name))
     ///     .from(Char::Table)
     ///     .join(JoinType::RightJoin, Font::Table, Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
     ///     .group_by_columns(vec![
@@ -961,7 +1055,7 @@ impl SelectStatement {
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
-    ///     .table_column(Font::Table, Font::Name)
+    ///     .column((Font::Table, Font::Name))
     ///     .from(Char::Table)
     ///     .join(JoinType::RightJoin, Font::Table, Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
     ///     .group_by_columns(vec![
@@ -1001,7 +1095,7 @@ impl SelectStatement {
     ///
     /// let query = Query::select()
     ///     .column(Char::Character)
-    ///     .table_column(Font::Table, Font::Name)
+    ///     .column((Font::Table, Font::Name))
     ///     .from(Char::Table)
     ///     .join(JoinType::RightJoin, Font::Table, Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
     ///     .group_by_col((Char::Table, Char::Character))
@@ -1048,7 +1142,7 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .from(Char::Table)
@@ -1076,7 +1170,7 @@ impl SelectStatement {
     where
         I: IntoIterator<Item = SimpleExpr>,
     {
-        self.groups.append(&mut Vec::from_iter(expr.into_iter()));
+        self.groups.append(&mut expr.into_iter().collect());
         self
     }
 
@@ -1199,7 +1293,7 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .column(Glyph::Aspect)
@@ -1236,7 +1330,7 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use sea_query::{*, tests_cfg::*};
+    /// use sea_query::{tests_cfg::*, *};
     ///
     /// let query = Query::select()
     ///     .column(Glyph::Aspect)
@@ -1268,6 +1362,102 @@ impl SelectStatement {
         self.offset = None;
         self
     }
+
+    /// Row locking (if supported).
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .column(Char::Character)
+    ///     .from(Char::Table)
+    ///     .and_where(Expr::col(Char::FontId).eq(5))
+    ///     .lock(LockType::Exclusive)
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character` FROM `character` WHERE `font_id` = 5 FOR UPDATE"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character" FROM "character" WHERE "font_id" = 5 FOR UPDATE"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT `character` FROM `character` WHERE `font_id` = 5 "#
+    /// );
+    /// ```
+    pub fn lock(&mut self, lock_type: LockType) -> &mut Self {
+        self.lock = Some(lock_type);
+        self
+    }
+
+    /// Shared row locking (if supported).
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .column(Char::Character)
+    ///     .from(Char::Table)
+    ///     .and_where(Expr::col(Char::FontId).eq(5))
+    ///     .lock_shared()
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character` FROM `character` WHERE `font_id` = 5 FOR SHARE"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character" FROM "character" WHERE "font_id" = 5 FOR SHARE"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT `character` FROM `character` WHERE `font_id` = 5 "#
+    /// );
+    /// ```
+    pub fn lock_shared(&mut self) -> &mut Self {
+        self.lock = Some(LockType::Shared);
+        self
+    }
+
+    /// Exclusive row locking (if supported).
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .column(Char::Character)
+    ///     .from(Char::Table)
+    ///     .and_where(Expr::col(Char::FontId).eq(5))
+    ///     .lock_exclusive()
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character` FROM `character` WHERE `font_id` = 5 FOR UPDATE"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character" FROM "character" WHERE "font_id" = 5 FOR UPDATE"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT `character` FROM `character` WHERE `font_id` = 5 "#
+    /// );
+    /// ```
+    pub fn lock_exclusive(&mut self) -> &mut Self {
+        self.lock = Some(LockType::Exclusive);
+        self
+    }
 }
 
 impl QueryStatementBuilder for SelectStatement {
