@@ -72,14 +72,25 @@ pub enum Value {
     BigDecimal(Option<Box<BigDecimal>>),
 }
 
-pub trait ValueType: ValueTypeDefault {
-    fn unwrap(v: Value) -> Self;
+pub trait ValueType: Sized {
+    fn try_from(v: Value) -> Result<Self, ValueTypeErr>;
 
-    fn type_name() -> &'static str;
+    fn unwrap(v: Value) -> Self {
+        Self::try_from(v).unwrap()
+    }
+
+    fn type_name() -> String;
 }
 
-pub trait ValueTypeDefault {
-    fn default() -> Self;
+#[derive(Debug)]
+pub struct ValueTypeErr;
+
+impl std::error::Error for ValueTypeErr {}
+
+impl std::fmt::Display for ValueTypeErr {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        write!(f, "Value type mismatch")
+    }
 }
 
 #[derive(Clone, Debug, PartialEq)]
@@ -96,6 +107,10 @@ pub trait IntoValueTuple {
     fn into_value_tuple(self) -> ValueTuple;
 }
 
+pub trait Nullable {
+    fn null() -> Value;
+}
+
 impl Value {
     pub fn unwrap<T>(self) -> T
     where
@@ -113,50 +128,22 @@ macro_rules! type_to_value {
             }
         }
 
-        impl From<Option<$type>> for Value {
-            fn from(x: Option<$type>) -> Value {
-                Value::$name(x)
+        impl Nullable for $type {
+            fn null() -> Value {
+                Value::$name(None)
             }
         }
 
         impl ValueType for $type {
-            fn unwrap(v: Value) -> Self {
+            fn try_from(v: Value) -> Result<Self, ValueTypeErr> {
                 match v {
-                    Value::$name(Some(x)) => x,
-                    _ => panic!("type error"),
+                    Value::$name(Some(x)) => Ok(x),
+                    _ => Err(ValueTypeErr),
                 }
             }
 
-            fn type_name() -> &'static str {
-                stringify!($type)
-            }
-        }
-
-        impl ValueTypeDefault for $type
-        where
-            $type: Default,
-        {
-            fn default() -> Self {
-                Default::default()
-            }
-        }
-
-        impl ValueType for Option<$type> {
-            fn unwrap(v: Value) -> Self {
-                match v {
-                    Value::$name(x) => x,
-                    _ => panic!("type error"),
-                }
-            }
-
-            fn type_name() -> &'static str {
-                concat!("Option<", stringify!($type), ">")
-            }
-        }
-
-        impl ValueTypeDefault for Option<$type> {
-            fn default() -> Self {
-                Default::default()
+            fn type_name() -> String {
+                stringify!($type).to_owned()
             }
         }
     };
@@ -170,55 +157,22 @@ macro_rules! type_to_box_value {
             }
         }
 
-        impl From<Option<$type>> for Value {
-            fn from(x: Option<$type>) -> Value {
-                match x {
-                    Some(v) => Value::$name(Some(Box::new(v))),
-                    None => Value::$name(None),
-                }
+        impl Nullable for $type {
+            fn null() -> Value {
+                Value::$name(None)
             }
         }
 
         impl ValueType for $type {
-            fn unwrap(v: Value) -> Self {
+            fn try_from(v: Value) -> Result<Self, ValueTypeErr> {
                 match v {
-                    Value::$name(Some(x)) => *x,
-                    _ => panic!("type error"),
+                    Value::$name(Some(x)) => Ok(*x),
+                    _ => Err(ValueTypeErr),
                 }
             }
 
-            fn type_name() -> &'static str {
-                stringify!($type)
-            }
-        }
-
-        impl ValueType for Option<$type> {
-            fn unwrap(v: Value) -> Self {
-                match v {
-                    Value::$name(Some(x)) => Some(*x),
-                    Value::$name(None) => None,
-                    _ => panic!("type error"),
-                }
-            }
-
-            fn type_name() -> &'static str {
-                concat!("Option<", stringify!($type), ">")
-            }
-        }
-
-        impl ValueTypeDefault for Option<$type> {
-            fn default() -> Self {
-                Default::default()
-            }
-        }
-    };
-}
-
-macro_rules! impl_value_type_default {
-    ( $type: ty ) => {
-        impl ValueTypeDefault for $type {
-            fn default() -> Self {
-                Default::default()
+            fn type_name() -> String {
+                stringify!($type).to_owned()
             }
         }
     };
@@ -249,10 +203,43 @@ impl<'a> From<&'a str> for Value {
     }
 }
 
+impl<'a> Nullable for &'a str {
+    fn null() -> Value {
+        Value::String(None)
+    }
+}
+
+impl<T> From<Option<T>> for Value
+where
+    T: Into<Value> + Nullable,
+{
+    fn from(x: Option<T>) -> Value {
+        match x {
+            Some(v) => v.into(),
+            None => T::null(),
+        }
+    }
+}
+
+impl<T> ValueType for Option<T>
+where
+    T: ValueType + Nullable,
+{
+    fn try_from(v: Value) -> Result<Self, ValueTypeErr> {
+        if v == T::null() {
+            Ok(None)
+        } else {
+            Ok(Some(T::try_from(v)?))
+        }
+    }
+
+    fn type_name() -> String {
+        format!("Option<{}>", T::type_name())
+    }
+}
+
 type_to_box_value!(Vec<u8>, Bytes);
-impl_value_type_default!(Vec<u8>);
 type_to_box_value!(String, String);
-impl_value_type_default!(String);
 
 #[cfg(feature = "with-json")]
 #[cfg_attr(docsrs, doc(cfg(feature = "with-json")))]
@@ -260,7 +247,6 @@ mod with_json {
     use super::*;
 
     type_to_box_value!(Json, Json);
-    impl_value_type_default!(Json);
 }
 
 #[cfg(feature = "with-chrono")]
@@ -273,36 +259,6 @@ mod with_chrono {
     type_to_box_value!(NaiveTime, Time);
     type_to_box_value!(NaiveDateTime, DateTime);
 
-    impl ValueTypeDefault for NaiveDate {
-        fn default() -> Self {
-            NaiveDate::from_num_days_from_ce(0)
-        }
-    }
-
-    impl ValueTypeDefault for NaiveTime {
-        fn default() -> Self {
-            NaiveTime::from_hms(0, 0, 0)
-        }
-    }
-
-    impl ValueTypeDefault for NaiveDateTime {
-        fn default() -> Self {
-            NaiveDateTime::from_timestamp(0, 0)
-        }
-    }
-
-    impl ValueTypeDefault for DateTime<FixedOffset> {
-        fn default() -> Self {
-            DateTime::from_utc(NaiveDateTime::from_timestamp(0, 0), FixedOffset::east(0))
-        }
-    }
-
-    impl ValueTypeDefault for Option<DateTime<FixedOffset>> {
-        fn default() -> Self {
-            Default::default()
-        }
-    }
-
     impl<Tz> From<DateTime<Tz>> for Value
     where
         Tz: TimeZone,
@@ -313,41 +269,22 @@ mod with_chrono {
         }
     }
 
-    impl<Tz> From<Option<DateTime<Tz>>> for Value
-    where
-        Tz: TimeZone,
-    {
-        fn from(x: Option<DateTime<Tz>>) -> Value {
-            match x {
-                Some(v) => From::<DateTime<Tz>>::from(v),
-                None => Value::DateTimeWithTimeZone(None),
-            }
+    impl Nullable for DateTime<FixedOffset> {
+        fn null() -> Value {
+            Value::DateTimeWithTimeZone(None)
         }
     }
 
     impl ValueType for DateTime<FixedOffset> {
-        fn unwrap(v: Value) -> Self {
+        fn try_from(v: Value) -> Result<Self, ValueTypeErr> {
             match v {
-                Value::DateTimeWithTimeZone(Some(x)) => *x,
-                _ => panic!("type error"),
+                Value::DateTimeWithTimeZone(Some(x)) => Ok(*x),
+                _ => Err(ValueTypeErr),
             }
         }
 
-        fn type_name() -> &'static str {
-            stringify!(DateTime<FixedOffset>)
-        }
-    }
-
-    impl ValueType for Option<DateTime<FixedOffset>> {
-        fn unwrap(v: Value) -> Self {
-            match v {
-                Value::DateTimeWithTimeZone(Some(x)) => Some(*x),
-                _ => panic!("type error"),
-            }
-        }
-
-        fn type_name() -> &'static str {
-            stringify!(Option<DateTime<FixedOffset>>)
+        fn type_name() -> String {
+            stringify!(DateTime<FixedOffset>).to_owned()
         }
     }
 }
@@ -358,7 +295,6 @@ mod with_rust_decimal {
     use super::*;
 
     type_to_box_value!(Decimal, Decimal);
-    impl_value_type_default!(Decimal);
 }
 
 #[cfg(feature = "with-bigdecimal")]
@@ -367,7 +303,6 @@ mod with_bigdecimal {
     use super::*;
 
     type_to_box_value!(BigDecimal, BigDecimal);
-    impl_value_type_default!(BigDecimal);
 }
 
 #[cfg(feature = "with-uuid")]
@@ -376,7 +311,6 @@ mod with_uuid {
     use super::*;
 
     type_to_box_value!(Uuid, Uuid);
-    impl_value_type_default!(Uuid);
 }
 
 impl Value {
