@@ -694,22 +694,6 @@ fn select_43() {
     assert_eq!(statement, r#"SELECT `id` FROM `glyph`"#);
 }
 
-#[test]
-#[allow(clippy::approx_constant)]
-#[cfg(feature = "with-json")]
-fn insert_1() {
-    assert_eq!(
-        Query::insert()
-            .into_table(Glyph::Table)
-            .json(json!({
-                "image": "24B0E11951B03B07F8300FD003983F03F0780060",
-                "aspect": 2.1345,
-            }))
-            .to_string(SqliteQueryBuilder),
-        "INSERT INTO `glyph` (`aspect`, `image`) VALUES (2.1345, '24B0E11951B03B07F8300FD003983F03F0780060')"
-    );
-}
-
 #[test]
 #[allow(clippy::approx_constant)]
 fn insert_2() {
@@ -744,7 +728,7 @@ fn insert_3() {
                 3.1415.into(),
             ])
             .values_panic(vec![
-                Value::Null,
+                Value::Double(None),
                 2.1345.into(),
             ])
             .to_string(SqliteQueryBuilder),
@@ -793,22 +777,6 @@ fn update_1() {
     );
 }
 
-#[test]
-#[cfg(feature = "with-json")]
-fn update_2() {
-    assert_eq!(
-        Query::update()
-            .table(Glyph::Table)
-            .json(json!({
-                "aspect": 2.1345,
-                "image": "24B0E11951B03B07F8300FD003983F03F0780060",
-            }))
-            .and_where(Expr::col(Glyph::Id).eq(1))
-            .to_string(SqliteQueryBuilder),
-        "UPDATE `glyph` SET `aspect` = 2.1345, `image` = '24B0E11951B03B07F8300FD003983F03F0780060' WHERE `id` = 1"
-    );
-}
-
 #[test]
 fn update_3() {
     assert_eq!(
